==> shande-sdk-1.0.0.20221202-sources.jar: com/fshows/com/shande/openapi/sdk/service/AbstractOpenApiService.java <==
package com.fshows.com.shande.openapi.sdk.service;

import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.fshows.com.shande.openapi.sdk.client.OpenParameters;
import com.fshows.com.shande.openapi.sdk.client.ShandeOpenApiClient;
import com.fshows.com.shande.openapi.sdk.config.Configuration;
import com.fshows.com.shande.openapi.sdk.constant.AlgorithmTypeEnum;
import com.fshows.com.shande.openapi.sdk.constant.RequestConstants;
import com.fshows.com.shande.openapi.sdk.crypto.CryptoEncryptionService;
import com.fshows.com.shande.openapi.sdk.crypto.CryptoSignatureService;
import com.fshows.com.shande.openapi.sdk.util.AESUtils;
import com.fshows.com.shande.openapi.sdk.util.CryptoServiceUtils;
import com.fshows.com.shande.openapi.sdk.util.SerialNoUtils;
import com.fshows.shande.sdk.common.ReqIdUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.nio.charset.Charset;
import java.util.Map;
import java.util.TreeMap;

/**
 * @author miwenming
 * @date 2020/5/28 20:53
 */
public abstract class AbstractOpenApiService implements OpenApiService {
    final Logger logger = LoggerFactory.getLogger(getClass());

    @Override
    public String execute(ShandeOpenApiClient client, OpenParameters context) throws Exception {
        HttpURLConnection connection = null;
        try {
            Configuration configuration = client.getConfiguration();
            // 组装请求报文体
            String body = buildBody(configuration, context);
            // 获取请求连接
            connection = getHttpURLConnection(configuration, context);
            byte[] response = getResponse(connection, body, configuration.charset());
            String result = verifyAndDecrypt(connection, configuration, context, response);
            logger.debug("request >> 衫德请求结束 >> url={}, request={}, result = {}", connection.getURL(), body, result);
            return result;
        } finally {
            if (connection != null) {
                connection.disconnect();
            }
        }
    }

    /**
     * 组装请求报文体
     *
     * @param configuration 配置对象
     * @param context       请求上下文
     */
    private String buildBody(Configuration configuration, OpenParameters context) throws Exception {
        String randomKey = AESUtils.randomKey();
        String encryptType = configuration.encryptType();
        String signType = configuration.signType();
        CryptoEncryptionService rsaEncryptionService = CryptoServiceUtils.getCryptoRSAEncryptionService(signType);
        //使用平台公钥对随机16位字符串进行RSA加密
        String randomKeyEncrypt = rsaEncryptionService.encrypt(randomKey, configuration.shandeEncPubKey());
        logger.debug("signType is {}, randomKeyEncrypt is {}", signType, randomKeyEncrypt);

        CryptoEncryptionService aesEncryptionService = CryptoServiceUtils.getCryptoAESEncryptionService(encryptType);
        //使用随机16位字符串对请求参数进行AES加密
        String data = aesEncryptionService.encrypt(context.getParams(), randomKey);
        logger.debug("randomKey is {}, encryptType is {}, encrypt result is {}", randomKey, encryptType, data);

        TreeMap<String, Object> requestMap = new TreeMap<>();
        requestMap.put(RequestConstants.RequestBody.KEY_MID, configuration.mid());
        requestMap.put(RequestConstants.RequestBody.KEY_TIMESTAMP, DateUtil.now());
        requestMap.put(RequestConstants.RequestBody.KEY_VERSION, RequestConstants.SDK.VERSION);
        requestMap.put(RequestConstants.RequestBody.KEY_CUSTOMER_ORDER_NO, ReqIdUtil.getId());
        requestMap.put(RequestConstants.RequestBody.KEY_SIGN_TYPE, "SHA1WithRSA");
        requestMap.put(RequestConstants.RequestBody.KEY_ENCRYPT_TYPE, "AES");
        requestMap.put(RequestConstants.RequestBody.KEY_ENCRYPT_KEY, randomKeyEncrypt);
        requestMap.put(RequestConstants.RequestBody.KEY_DATA, data);

        JSONObject orderRequestMap = AESUtils.getAloneKeys(new JSONObject(requestMap));
        String preSignData = AESUtils.getPreSignData(orderRequestMap);
        CryptoSignatureService cryptoSignatureService = CryptoServiceUtils.getCryptoSignatureService(signType);
        // 对加密后的输入参数签名
        String signData = cryptoSignatureService.signature(preSignData, configuration);
        logger.debug("signature result is {}", signData);
        orderRequestMap.put(RequestConstants.RequestBody.KEY_SIGN, signData);
        logger.debug("request >> 衫德请求开始 >> orderRequestMap = {}", orderRequestMap);
        return orderRequestMap.toJSONString();
    }

    /**
     * 获取HttpURLConnection连接
     *
     * @param configuration 配置对象
     * @param context 请求上下文
     */
    private HttpURLConnection getHttpURLConnection(Configuration configuration, OpenParameters context)
            throws IOException {
        URL url = new URL(pseudoModuleCode(context, getRemoteAddress(configuration)));
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        // 设置http 的通用请求头
        setHttpHeaders(configuration, context, connection);
        // 需要输出
        connection.setDoOutput(true);
        // 需要输入
        connection.setDoInput(true);
        // 不允许缓存
        connection.setUseCaches(false);
        // 暂时仅支持POST方法
        connection.setRequestMethod(getHttpMethod());
        // 设置连接超时时间
        connection.setConnectTimeout(configuration.connectionTimeout());
        // 设置读取超时时间
        connection.setReadTimeout(configuration.readTimeout());

        return connection;
    }

    /**
     * 获取请求地址
     *
     * @param configuration 配置对象
     */
    protected String getRemoteAddress(Configuration configuration) {
        return configuration.remoteAddress();
    }

    /**
     * 转换请求地址 对于module_code为openapi-function的请求，将api_code的值以?function=XXXXXX形式拼接到请求地址上
     *
     * @param context 请求上下文
     * @param address 请求地址
     */
    private String pseudoModuleCode(OpenParameters context, String address) {
        address += context.getApiName();
        return address;
    }

    /**
     * 设置HTTP请求头
     *
     * @param configuration 配置对象
     * @param context 请求上下文
     * @param connection HttpURLConnection对象
     */
    private void setHttpHeaders(Configuration configuration, OpenParameters context, HttpURLConnection connection) {
        connection.setRequestProperty(RequestConstants.RequestHeader.KEY_API_NAME, context.getApiName());
        setAlgorithm(configuration, connection);
        String clientSerialNo = SerialNoUtils.calculateSerialNo(context.getParams());
        connection.setRequestProperty(RequestConstants.RequestHeader.KEY_CLIENT_SERIAL_NO, clientSerialNo);
        connection.setRequestProperty("Content-Type", "application/json");
    }

    protected void setAlgorithm(Configuration configuration, HttpURLConnection connection) {
        // 硬件服务器签名服务需要上送algorithm请求为rsaDetached
        if (AlgorithmTypeEnum.RSA_HARDWARE.getAlgorithmType().equals(configuration.signType())) {
            connection.setRequestProperty(RequestConstants.RequestHeader.KEY_ALGORITHM,
                    RequestConstants.AlgorithmService.ALGORITHM_TYPE_RSA_DETACHED);
        }
    }

    /**
     * 获取HTTP请求方法，默认为POST
     */
    protected String getHttpMethod() {
        return "POST";
    }

    /**
     * 解析响应结果，关闭输入输出流
     *
     * @param connection HttpURLConnection实例
     * @param encryptedBody 加密报文
     * @param charset 所使用字符集
     */
    private byte[] getResponse(HttpURLConnection connection, String encryptedBody, Charset charset)
            throws IOException {
        try (OutputStream outputStream = connection.getOutputStream()) {
            if (null != encryptedBody) {
                // 发送请求数据
                outputStream.write(encryptedBody.getBytes(charset));
                outputStream.flush();
            }
        }
        try (InputStream in = connection.getInputStream()) {
            // 读取数据到字节数组
            return read(in);
        }
    }

    /**
     * 读取数据到字节数组
     *
     * @param inputStream 输入流
     */
    private byte[] read(InputStream inputStream) throws IOException {
        try (ByteArrayOutputStream outputStream = new ByteArrayOutputStream()) {
            final int defaultBufferSize = 1024 * 8;
            byte[] buffer = new byte[defaultBufferSize];
            int num;

            logger.debug("read data begin");
            while ((num = inputStream.read(buffer)) != -1) {
                outputStream.write(buffer, 0, num);
            }
            byte[] readResult = outputStream.toByteArray();
            logger.debug("read data end");

            return readResult;
        }
    }

    /**
     * 验签解密
     *
     * @param connection HttpURLConnection连接实例
     * @param configuration 配置对象
     * @param context 上下文
     * @param response 响应报文
     */
    public String verifyAndDecrypt(HttpURLConnection connection, Configuration configuration,
                                   OpenParameters context, byte[] response)
            throws Exception {
        String responseStr = new String(response, configuration.charset());
        // 使用双证书版本的公钥进行加密
        String pubKey = configuration.shandeEncPubKey();
        // 签名验证，失败抛出异常
        JSONObject json = verifySignature(configuration, responseStr, pubKey);
        // 解密返回结果
        String dataResult = decryptResult(configuration, json);
        json.put("data", dataResult);
        return json.toString();
    }

    /**
     * 对响应结果进行签名验证
     *
     * @param encryptedResult 加密签名后的数据
     * @param publicKey 平台公钥
     * @return 根据响应结果解析的json对象
     */
    private JSONObject verifySignature(Configuration configuration, String encryptedResult, String publicKey)
            throws Exception {
        Map<String, Object> encryptedResultMap
                = JSONObject.parseObject(encryptedResult, new TypeReference<TreeMap<String, Object>>() {
        });
        Object signData = encryptedResultMap.remove(RequestConstants.RequestBody.KEY_SIGN);
        JSONObject encryptedResultJson = new JSONObject(encryptedResultMap);
        CryptoSignatureService cryptoService = CryptoServiceUtils.getCryptoSignatureService(configuration.signType());


        String preSignData = AESUtils.getPreSignData(encryptedResultJson);

        boolean verifyResult = cryptoService.verifySignature(
                preSignData, signData.toString(), publicKey);
        if (!verifyResult) {
            logger.error("The result signature verify failed, encryptedResult is : {} ", encryptedResult);
            throw new IllegalArgumentException("Verify signature failed.");
        }
        return encryptedResultJson;
    }

    /**
     * 解密AES密钥，然后用AES密钥对返回结果进行解密
     *
     * @param configuration 配置类
     * @param json 根据返回结果得到的json对象
     * @return 解密后的业务数据
     */
    private String decryptResult(Configuration configuration, JSONObject json) throws Exception {
        String encryptedRandomKey = json.getString(RequestConstants.RequestBody.KEY_ENCRYPT_KEY);
        CryptoEncryptionService rsaCryptoEncryptionService
                = CryptoServiceUtils.getCryptoRSAEncryptionService(configuration.signType());
        String randomKey = rsaCryptoEncryptionService.decrypt(encryptedRandomKey, configuration.fubeiSignPrivateKey());

        CryptoEncryptionService aesCryptoEncryptionService
                = CryptoServiceUtils.getCryptoAESEncryptionService(configuration.encryptType());
        return aesCryptoEncryptionService.decrypt(json.getString(RequestConstants.RequestBody.KEY_DATA), randomKey);
    }
}

==> shande-sdk-1.0.0.20230410-20230331.021633-1-sources.jar: com/fshows/com/shande/openapi/sdk/service/AbstractOpenApiService.java <==
package com.fshows.com.shande.openapi.sdk.service;

import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.fshows.com.shande.openapi.sdk.client.OpenParameters;
import com.fshows.com.shande.openapi.sdk.client.ShandeOpenApiClient;
import com.fshows.com.shande.openapi.sdk.config.Configuration;
import com.fshows.com.shande.openapi.sdk.constant.AlgorithmTypeEnum;
import com.fshows.com.shande.openapi.sdk.constant.RequestConstants;
import com.fshows.com.shande.openapi.sdk.constant.RequestVerifyTypeEnum;
import com.fshows.com.shande.openapi.sdk.crypto.CryptoEncryptionService;
import com.fshows.com.shande.openapi.sdk.crypto.CryptoSignatureService;
import com.fshows.com.shande.openapi.sdk.util.AESUtils;
import com.fshows.com.shande.openapi.sdk.util.CryptoServiceUtils;
import com.fshows.com.shande.openapi.sdk.util.SerialNoUtils;
import com.fshows.shande.sdk.common.ReqIdUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.nio.charset.Charset;
import java.util.Map;
import java.util.TreeMap;

/**
 * @author miwenming
 * @date 2020/5/28 20:53
 */
public abstract class AbstractOpenApiService implements OpenApiService {
    final Logger logger = LoggerFactory.getLogger(getClass());

    @Override
    public String execute(ShandeOpenApiClient client, OpenParameters context) throws Exception {
        HttpURLConnection connection = null;
        try {
            Configuration configuration = client.getConfiguration();
            // 组装请求报文体
            String body = buildBody(configuration, context);
            // 获取请求连接
            connection = getHttpURLConnection(configuration, context);
            byte[] response = getResponse(connection, body, configuration.charset());
            String result = verifyAndDecrypt(connection, configuration, context, response);
            logger.debug("request >> 衫德请求结束 >> url={}, request={}, result = {}", connection.getURL(), body, result);
            return result;
        } finally {
            if (connection != null) {
                connection.disconnect();
            }
        }
    }

    /**
     * 组装请求报文体
     *
     * @param configuration 配置对象
     * @param context       请求上下文
     */
    private String buildBody(Configuration configuration, OpenParameters context) throws Exception {
        String randomKey = AESUtils.randomKey();
        String encryptType = configuration.encryptType();
        String signType = configuration.signType();
        CryptoEncryptionService rsaEncryptionService = CryptoServiceUtils.getCryptoRSAEncryptionService(signType);
        //使用平台公钥对随机16位字符串进行RSA加密
        String shandeEncPubKey = this.matchesShandeEncPubKey(context.getVerifyTypeEnum(), configuration);
        String randomKeyEncrypt = rsaEncryptionService.encrypt(randomKey, shandeEncPubKey);
        logger.debug("signType is {}, randomKeyEncrypt is {}", signType, randomKeyEncrypt);

        CryptoEncryptionService aesEncryptionService = CryptoServiceUtils.getCryptoAESEncryptionService(encryptType);
        //使用随机16位字符串对请求参数进行AES加密
        String data = aesEncryptionService.encrypt(context.getParams(), randomKey);
        logger.debug("randomKey is {}, encryptType is {}, encrypt result is {}", randomKey, encryptType, data);

        TreeMap<String, Object> requestMap = new TreeMap<>();
        requestMap.put(RequestConstants.RequestBody.KEY_MID, configuration.mid());
        requestMap.put(RequestConstants.RequestBody.KEY_TIMESTAMP, DateUtil.now());
        requestMap.put(RequestConstants.RequestBody.KEY_VERSION, RequestConstants.SDK.VERSION);
        requestMap.put(RequestConstants.RequestBody.KEY_CUSTOMER_ORDER_NO, ReqIdUtil.getId());
        requestMap.put(RequestConstants.RequestBody.KEY_SIGN_TYPE, "SHA1WithRSA");
        requestMap.put(RequestConstants.RequestBody.KEY_ENCRYPT_TYPE, "AES");
        requestMap.put(RequestConstants.RequestBody.KEY_ENCRYPT_KEY, randomKeyEncrypt);
        requestMap.put(RequestConstants.RequestBody.KEY_DATA, data);

        JSONObject orderRequestMap = AESUtils.getAloneKeys(new JSONObject(requestMap));
        String preSignData = AESUtils.getPreSignData(orderRequestMap);
        CryptoSignatureService cryptoSignatureService = CryptoServiceUtils.getCryptoSignatureService(signType);
        // 对加密后的输入参数签名
        String fubeiSignPrivateKey = this.matchesFubeiSignPrivateKey(context.getVerifyTypeEnum(), configuration);
        String signData = cryptoSignatureService.signature(preSignData, fubeiSignPrivateKey);
        logger.debug("signature result is {}", signData);
        orderRequestMap.put(RequestConstants.RequestBody.KEY_SIGN, signData);
        logger.debug("request >> 衫德请求开始 >> orderRequestMap = {}", orderRequestMap);
        return orderRequestMap.toJSONString();
    }

    /**
     * 匹配杉德响应验证公钥
     * @param verifyTypeEnum
     * @param configuration
     * @return
     */
    public String matchesShandeEncPubKey(RequestVerifyTypeEnum verifyTypeEnum,Configuration configuration){
        String shandeEncPubKey=null;
        if (RequestVerifyTypeEnum.ACCOUNT_OPENING.equals(verifyTypeEnum)) {
            shandeEncPubKey = configuration.shandeAccountOpeningEncPubKey();
        }else if(RequestVerifyTypeEnum.OUT_FUND.equals(verifyTypeEnum)){
            shandeEncPubKey = configuration.shandeOutFundEncPubKey();
        }else if(RequestVerifyTypeEnum.IN_FUND.equals(verifyTypeEnum)){

        }
        return shandeEncPubKey;
    }

    public String matchesFubeiSignPrivateKey(RequestVerifyTypeEnum verifyTypeEnum,Configuration configuration){
        String fubeiSignPrivateKey=null;
        if (RequestVerifyTypeEnum.ACCOUNT_OPENING.equals(verifyTypeEnum)) {
            fubeiSignPrivateKey = configuration.fubeiAccountOpeningSignPrivateKey();
        }else if(RequestVerifyTypeEnum.OUT_FUND.equals(verifyTypeEnum)){
            fubeiSignPrivateKey = configuration.fubeiOutFundSignPrivateKey();
        }else if(RequestVerifyTypeEnum.IN_FUND.equals(verifyTypeEnum)){

        }
        return fubeiSignPrivateKey;
    }
    /**
     * 获取HttpURLConnection连接
     *
     * @param configuration 配置对象
     * @param context 请求上下文
     */
    private HttpURLConnection getHttpURLConnection(Configuration configuration, OpenParameters context)
            throws IOException {
        URL url = new URL(pseudoModuleCode(context, getRemoteAddress(configuration)));
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        // 设置http 的通用请求头
        setHttpHeaders(configuration, context, connection);
        // 需要输出
        connection.setDoOutput(true);
        // 需要输入
        connection.setDoInput(true);
        // 不允许缓存
        connection.setUseCaches(false);
        // 暂时仅支持POST方法
        connection.setRequestMethod(getHttpMethod());
        // 设置连接超时时间
        connection.setConnectTimeout(configuration.connectionTimeout());
        // 设置读取超时时间
        connection.setReadTimeout(configuration.readTimeout());

        return connection;
    }

    /**
     * 获取请求地址
     *
     * @param configuration 配置对象
     */
    protected String getRemoteAddress(Configuration configuration) {
        return configuration.remoteAddress();
    }

    /**
     * 转换请求地址 对于module_code为openapi-function的请求，将api_code的值以?function=XXXXXX形式拼接到请求地址上
     *
     * @param context 请求上下文
     * @param address 请求地址
     */
    private String pseudoModuleCode(OpenParameters context, String address) {
        address += context.getApiName();
        return address;
    }

    /**
     * 设置HTTP请求头
     *
     * @param configuration 配置对象
     * @param context 请求上下文
     * @param connection HttpURLConnection对象
     */
    private void setHttpHeaders(Configuration configuration, OpenParameters context, HttpURLConnection connection) {
        connection.setRequestProperty(RequestConstants.RequestHeader.KEY_API_NAME, context.getApiName());
        setAlgorithm(configuration, connection);
        String clientSerialNo = SerialNoUtils.calculateSerialNo(context.getParams());
        connection.setRequestProperty(RequestConstants.RequestHeader.KEY_CLIENT_SERIAL_NO, clientSerialNo);
        connection.setRequestProperty("Content-Type", "application/json");
    }

    protected void setAlgorithm(Configuration configuration, HttpURLConnection connection) {
        // 硬件服务器签名服务需要上送algorithm请求为rsaDetached
        if (AlgorithmTypeEnum.RSA_HARDWARE.getAlgorithmType().equals(configuration.signType())) {
            connection.setRequestProperty(RequestConstants.RequestHeader.KEY_ALGORITHM,
                    RequestConstants.AlgorithmService.ALGORITHM_TYPE_RSA_DETACHED);
        }
    }

    /**
     * 获取HTTP请求方法，默认为POST
     */
    protected String getHttpMethod() {
        return "POST";
    }

    /**
     * 解析响应结果，关闭输入输出流
     *
     * @param connection HttpURLConnection实例
     * @param encryptedBody 加密报文
     * @param charset 所使用字符集
     */
    private byte[] getResponse(HttpURLConnection connection, String encryptedBody, Charset charset)
            throws IOException {
        try (OutputStream outputStream = connection.getOutputStream()) {
            if (null != encryptedBody) {
                // 发送请求数据
                outputStream.write(encryptedBody.getBytes(charset));
                outputStream.flush();
            }
        }
        try (InputStream in = connection.getInputStream()) {
            // 读取数据到字节数组
            return read(in);
        }
    }

    /**
     * 读取数据到字节数组
     *
     * @param inputStream 输入流
     */
    private byte[] read(InputStream inputStream) throws IOException {
        try (ByteArrayOutputStream outputStream = new ByteArrayOutputStream()) {
            final int defaultBufferSize = 1024 * 8;
            byte[] buffer = new byte[defaultBufferSize];
            int num;

            logger.debug("read data begin");
            while ((num = inputStream.read(buffer)) != -1) {
                outputStream.write(buffer, 0, num);
            }
            byte[] readResult = outputStream.toByteArray();
            logger.debug("read data end");

            return readResult;
        }
    }

    /**
     * 验签解密
     *
     * @param connection HttpURLConnection连接实例
     * @param configuration 配置对象
     * @param context 上下文
     * @param response 响应报文
     */
    public String verifyAndDecrypt(HttpURLConnection connection, Configuration configuration,
                                   OpenParameters context, byte[] response)
            throws Exception {
        String responseStr = null;
        try {
            responseStr = new String(response, configuration.charset());
            // 使用双证书版本的公钥进行加密
            String shandeEncPubKey = this.matchesShandeEncPubKey(context.getVerifyTypeEnum(), configuration);
            // 签名验证，失败抛出异常
            JSONObject json = verifySignature(configuration, responseStr, shandeEncPubKey);
            // 解密返回结果
            String dataResult = decryptResult(configuration,context,json);
            json.put("data", dataResult);
            return json.toString();
        } catch (Exception e) {
            logger.error("request >> 衫德请求结束 >> 请求杉德验签失败 >> url={}, request = {}, response={}",
                    pseudoModuleCode(context, getRemoteAddress(configuration)), context.getParams(), responseStr);
            throw e;
        }
    }

    /**
     * 对响应结果进行签名验证
     *
     * @param encryptedResult 加密签名后的数据
     * @param publicKey 平台公钥
     * @return 根据响应结果解析的json对象
     */
    private JSONObject verifySignature(Configuration configuration, String encryptedResult, String publicKey)
            throws Exception {
        Map<String, Object> encryptedResultMap
                = JSONObject.parseObject(encryptedResult, new TypeReference<TreeMap<String, Object>>() {
        });
        Object signData = encryptedResultMap.remove(RequestConstants.RequestBody.KEY_SIGN);
        JSONObject encryptedResultJson = new JSONObject(encryptedResultMap);
        CryptoSignatureService cryptoService = CryptoServiceUtils.getCryptoSignatureService(configuration.signType());


        String preSignData = AESUtils.getPreSignData(encryptedResultJson);

        boolean verifyResult = cryptoService.verifySignature(
                preSignData, signData.toString(), publicKey);
        if (!verifyResult) {
            logger.error("The result signature verify failed, encryptedResult is : {} ", encryptedResult);
            throw new IllegalArgumentException("Verify signature failed.");
        }
        return encryptedResultJson;
    }

    /**
     * 解密AES密钥，然后用AES密钥对返回结果进行解密
     *
     * @param configuration 配置类
     * @param json 根据返回结果得到的json对象
     * @return 解密后的业务数据
     */
    public String decryptResult(Configuration configuration, OpenParameters context,JSONObject json) throws Exception {
        String encryptedRandomKey = json.getString(RequestConstants.RequestBody.KEY_ENCRYPT_KEY);
        CryptoEncryptionService rsaCryptoEncryptionService
                = CryptoServiceUtils.getCryptoRSAEncryptionService(configuration.signType());
        String fubeiSignPrivateKey = this.matchesFubeiSignPrivateKey(context.getVerifyTypeEnum(), configuration);
        String randomKey = rsaCryptoEncryptionService.decrypt(encryptedRandomKey, fubeiSignPrivateKey);

        CryptoEncryptionService aesCryptoEncryptionService
                = CryptoServiceUtils.getCryptoAESEncryptionService(configuration.encryptType());
        return aesCryptoEncryptionService.decrypt(json.getString(RequestConstants.RequestBody.KEY_DATA), randomKey);
    }
}
